Learn R Programming

fdakma (version 1.2.1)

kma.data: Simulated Data

Description

kma.data is a functional dataset displaying both amplitude and phase variability.

Usage

data(kma.data)

Arguments

Format

List of 3 elements: $x : abscissa values where each function is evaluated $y0: evaluations of the original functions on the abscissa grid kma.data$x $y1: evaluations of the original function first derivatives on the abscissa grid kma.data$x.

References

Sangalli, L.M., Secchi, P., Vantini, S., Vitelli, V., 2010. "K-mean alignment for curve clustering". Computational Statistics and Data Analysis, 54, 1219-1233.

Sangalli, L.M., Secchi, P., Vantini, S., 2014. "Analysis of AneuRisk65 data: K-mean Alignment". Electronic Journal of Statistics, Special Section on "Statistics of Time Warpings and Phase Variations", Vol. 8, No. 2, 1891-1904.

See Also

kma.compare, kma.similarity, fdakma, kma, kma.show.results

Examples

Run this code
data(kma.data)

x <- kma.data$x # abscissas
y0 <- kma.data$y0 # evaluations of original functions
y1 <- kma.data$y1 # evaluations of original function first derivatives

## Not run: 
# # Plot of original functions
# matplot(t(x),t(y0), type='l', xlab='x', ylab='orig.func')
# title ('Original functions')
# 
# # Plot of original function first derivatives
# matplot(t(x),t(y1), type='l', xlab='x', ylab='orig.deriv')
# title ('Original function first derivatives')
# ## End(Not run)

Run the code above in your browser using DataLab